import { render, screen, waitFor } from '@testing-library/react'
import React from 'react'
import { Provider } from 'react-redux'
import { defaultEcogestureData } from 'tests/__mocks__/actionData.mock'
import {
  createMockEcolyoStore,
  mockChallengeState,
  mockGlobalState,
  mockProfileState,
} from 'tests/__mocks__/store'
import ActionList from './ActionList'

const mockGetDefaultActions = jest.fn()

jest.mock('services/action.service', () => {
  return jest.fn(() => ({
    getDefaultActions: mockGetDefaultActions,
  }))
})

describe('ActionList component', () => {
  it('should match snapshot and render correctly 3 buttons', async () => {
    mockGetDefaultActions.mockResolvedValueOnce(defaultEcogestureData)
    const store = createMockEcolyoStore({
      challenge: { ...mockChallengeState },
      global: { ...mockGlobalState, fluidTypes: [0, 1, 2] },
      profile: mockProfileState,
    })
    const { container } = render(
      <Provider store={store}>
        <ActionList
          setSelectedAction={jest.fn()}
          setShowList={jest.fn()}
          setFocus={jest.fn()}
        />
      </Provider>
    )
    await waitFor(() => null, { container })
    expect(container).toMatchSnapshot()
    expect((await screen.findAllByRole('button')).length).toBe(3)
  })
})
