import CardActionArea, {
  CardActionAreaProps,
} from '@material-ui/core/CardActionArea'
import CardContent from '@material-ui/core/CardContent'
import { withStyles } from '@material-ui/core/styles'
import { FluidType } from 'enums'
import React, { ReactNode } from 'react'
import { getFluidName } from 'utils/utils'

const CardBase = withStyles({
  root: {
    background: 'var(--greyLinearGradientBackground)',
    boxSizing: 'border-box',
    boxShadow: '0px 4px 8px rgba(0, 0, 0, 0.75)',
    borderRadius: '4px',
  },
})(CardActionArea) as React.FC<StyledCardProps>

const CardContentBase = withStyles({
  root: {
    color: 'white',
    display: 'flex',
    alignItems: 'center',
    gap: '1rem',
    boxSizing: 'border-box',
  },
})(CardContent) as React.FC<StyledCardProps>

interface StyledCardProps extends CardActionAreaProps {
  fluidType?: FluidType
  children: ReactNode
}

const StyledCard = ({
  fluidType,
  children,
  className,
  ...props
}: StyledCardProps) => {
  const cardClass =
    className + (fluidType !== undefined ? ` ${getFluidName(fluidType)}` : '')

  return (
    <CardBase {...props} className={cardClass}>
      <CardContentBase>{children}</CardContentBase>
    </CardBase>
  )
}

export default StyledCard
