import Dialog from '@material-ui/core/Dialog'
import CloseIcon from 'assets/icons/ico/close.svg'
import star from 'assets/icons/visu/duel/star.svg'
import StyledIcon from 'components/CommonKit/Icon/StyledIcon'
import StyledIconButton from 'components/CommonKit/IconButton/StyledIconButton'
import { useI18n } from 'cozy-ui/transpiled/react/providers/I18n'
import React from 'react'
import './lastDuelModal.scss'

interface LastDuelModalProps {
  open: boolean
  handleCloseClick: () => void
}

const LastDuelModal = ({ open, handleCloseClick }: LastDuelModalProps) => {
  const { t } = useI18n()

  return (
    <Dialog
      open={open}
      onClose={handleCloseClick}
      aria-labelledby="accessibility-title"
      classes={{
        root: 'modal-root',
        paper: 'modal-paper blue-light-border',
      }}
    >
      <div id="accessibility-title">{t('last_duel_modal.title')}</div>
      <div className="duel-last-modal-root">
        <StyledIconButton
          icon={CloseIcon}
          onClick={handleCloseClick}
          aria-label={t('last_duel_modal.close')}
          className="modal-paper-close-button"
        />
        <StyledIcon className="icon" icon={star} size={48} />
        <h1 className="text-28-bold">{t('last_duel_modal.title')}</h1>
        <div>
          <h2 className="text-22-bold">{t('last_duel_modal.subtitle')}</h2>
          <p className="text-18-normal">{t('last_duel_modal.message1')}</p>
          <p className="text-18-normal">{t('last_duel_modal.message2')}</p>
        </div>
      </div>
    </Dialog>
  )
}

export default LastDuelModal
