import { PerformanceIndicator } from 'models'
import PerformanceIndicatorService from './performanceIndicator.service'

describe('performanceIndicator service', () => {
  describe('aggregatePerformanceIndicators method', () => {
    const performanceIndicatorService = new PerformanceIndicatorService()
    let performanceIndicator: PerformanceIndicator[] = [
      {
        value: 10,
        compareValue: 30,
        percentageVariation: 0.5,
      },
      {
        value: 40,
        compareValue: 15,
        percentageVariation: 0.2,
      },
      {
        value: 35,
        compareValue: 23,
        percentageVariation: 0.01,
      },
    ]

    it('should return the current timePeriod  and the comparison timePeriod for all timeStep', () => {
      let expectedResult: PerformanceIndicator = {
        value: 5.7911,
        compareValue: 7.84615,
        percentageVariation: -0.26191826564620857,
      }
      let result =
        performanceIndicatorService.aggregatePerformanceIndicators(
          performanceIndicator
        )
      expect(result).toEqual(expectedResult)

      // Only two values
      performanceIndicator = [
        {
          value: 10,
          compareValue: 30,
          percentageVariation: 0.5,
        },
        {
          value: 40,
          compareValue: 15,
          percentageVariation: 0.2,
        },
      ]
      expectedResult = {
        value: 1.8675999999999997,
        compareValue: 5.26785,
        percentageVariation: -0.6454720616570329,
      }
      result =
        performanceIndicatorService.aggregatePerformanceIndicators(
          performanceIndicator
        )
      expect(result).toEqual(expectedResult)

      // lack of value for one
      performanceIndicator = [
        {
          value: null,
          compareValue: 30,
          percentageVariation: 0.5,
        },
        {
          value: 40,
          compareValue: 15,
          percentageVariation: 0.2,
        },
        {
          value: 35,
          compareValue: 23,
          percentageVariation: 0.01,
        },
      ]
      expectedResult = {
        compareValue: 7.84615,
        percentageVariation: -0.48368308023680406,
        value: 4.0511,
      }
      result =
        performanceIndicatorService.aggregatePerformanceIndicators(
          performanceIndicator
        )
      expect(result).toEqual(expectedResult)

      // lack of compareValue for one
      performanceIndicator = [
        {
          value: 30,
          compareValue: null,
          percentageVariation: 0.5,
        },
        {
          value: 40,
          compareValue: 15,
          percentageVariation: 0.2,
        },
        {
          value: 35,
          compareValue: 23,
          percentageVariation: 0.01,
        },
      ]
      expectedResult = {
        value: 9.2711,
        compareValue: 0,
        percentageVariation: Infinity,
      }
      result =
        performanceIndicatorService.aggregatePerformanceIndicators(
          performanceIndicator
        )
      expect(result).toEqual(expectedResult)

      // Only one with no compared value
      performanceIndicator = [
        {
          value: 30,
          compareValue: null,
          percentageVariation: 0.5,
        },
      ]
      expectedResult = {
        value: 5.22,
        compareValue: 0,
        percentageVariation: Infinity,
      }
      result =
        performanceIndicatorService.aggregatePerformanceIndicators(
          performanceIndicator
        )
      expect(result).toEqual(expectedResult)

      // Only one with no value
      performanceIndicator = [
        {
          value: null,
          compareValue: 15,
          percentageVariation: 0.5,
        },
      ]
      expectedResult = {
        value: 0,
        compareValue: 2.61,
        percentageVariation: -1,
      }
      result =
        performanceIndicatorService.aggregatePerformanceIndicators(
          performanceIndicator
        )
      expect(result).toEqual(expectedResult)
    })
  })
})
