import { ModalState } from 'models'
import { mockCustomPopup } from 'tests/__mocks__/customPopup.mock'
import { mockModalState } from 'tests/__mocks__/store'
import {
  modalSlice,
  openFeedbackModal,
  openPartnersModal,
  setCustomPopup,
} from './modal.slice'

describe('modal reducer', () => {
  it('should return the initial state', () => {
    const initialState = modalSlice.getInitialState()
    expect(initialState).toEqual(mockModalState)
  })

  describe('openFeedbackModal', () => {
    it('should handle openFeedbackModal', () => {
      const state = modalSlice.reducer(mockModalState, openFeedbackModal(true))
      expect(state).toEqual({
        ...mockModalState,
        isFeedbacksOpen: true,
      })
    })
  })

  describe('openPartnersModal', () => {
    const partnersModalAllTrue = {
      egl: true,
      enedis: true,
      grdf: true,
    }
    it('should have all partners to false by default', () => {
      const state = modalSlice.getInitialState()
      const expectedResult: ModalState = {
        ...mockModalState,
        partnersIssueModal: {
          egl: false,
          enedis: false,
          grdf: false,
        },
      }
      expect(state).toEqual(expectedResult)
    })
    it('should handle openPartnersModal to set all partners to true', () => {
      const state = modalSlice.reducer(
        mockModalState,
        openPartnersModal({ egl: true, enedis: true, grdf: true })
      )
      const expectedResult: ModalState = {
        ...mockModalState,
        partnersIssueModal: {
          ...partnersModalAllTrue,
        },
      }
      expect(state).toEqual(expectedResult)
    })
    it('should handle openPartnersModal to set some partners to false', () => {
      const state = modalSlice.reducer(
        {
          ...mockModalState,
          partnersIssueModal: {
            ...partnersModalAllTrue,
          },
        },
        openPartnersModal({ egl: true, enedis: false, grdf: false })
      )
      const expectedResult: ModalState = {
        ...mockModalState,
        partnersIssueModal: {
          egl: true,
          enedis: false,
          grdf: false,
        },
      }
      expect(state).toEqual(expectedResult)
    })
  })

  describe('customPopup', () => {
    it('should handle setCustomPopup', () => {
      const state = modalSlice.reducer(
        mockModalState,
        setCustomPopup(mockCustomPopup)
      )
      expect(state).toEqual({
        ...mockModalState,
        customPopupModal: mockCustomPopup,
      })
    })
  })
})
